# Cubic Hermite Splines for Python

This module provides Python tools for cubic Hermite splines with one argument (time) and multiple values.
It was branched of from [JiTCDDE](http://github.com/neurophysik/jitcdde), which uses it for representing the past of a delay differential equation.

You can find the documentation [on Read the Docs](https://chspy.readthedocs.io).
